@@ -93,34 +93,34 @@ KompareShell::KompareShell()
     }
 
     // Hook up the inter part communication
-    connect(m_viewPart, SIGNAL(modelsChanged(const Diff2::DiffModelList*)),
-            m_navTreePart, SLOT(slotModelsChanged(const Diff2::DiffModelList*)));
+    connect(m_viewPart, SIGNAL(modelsChanged(const KompareDiff2::DiffModelList*)),
+            m_navTreePart, SLOT(slotModelsChanged(const KompareDiff2::DiffModelList*)));
 
-    connect(m_viewPart, SIGNAL(kompareInfo(Kompare::Info*)),
-            m_navTreePart, SLOT(slotKompareInfo(Kompare::Info*)));
+    connect(m_viewPart, SIGNAL(kompareInfo(KompareDiff2::Info*)),
+            m_navTreePart, SLOT(slotKompareInfo(KompareDiff2::Info*)));
 
-    connect(m_navTreePart, SIGNAL(selectionChanged(const Diff2::DiffModel*,const Diff2::Difference*)),
-            m_viewPart, SIGNAL(selectionChanged(const Diff2::DiffModel*,const Diff2::Difference*)));
-    connect(m_viewPart, SIGNAL(setSelection(const Diff2::DiffModel*,const Diff2::Difference*)),
-            m_navTreePart, SLOT(slotSetSelection(const Diff2::DiffModel*,const Diff2::Difference*)));
+    connect(m_navTreePart, SIGNAL(selectionChanged(const KompareDiff2::DiffModel*,const KompareDiff2::Difference*)),
+            m_viewPart, SIGNAL(selectionChanged(const KompareDiff2::DiffModel*,const KompareDiff2::Difference*)));
+    connect(m_viewPart, SIGNAL(setSelection(const KompareDiff2::DiffModel*,const KompareDiff2::Difference*)),
+            m_navTreePart, SLOT(slotSetSelection(const KompareDiff2::DiffModel*,const KompareDiff2::Difference*)));
 
-    connect(m_navTreePart, SIGNAL(selectionChanged(const Diff2::Difference*)),
-            m_viewPart, SIGNAL(selectionChanged(const Diff2::Difference*)));
-    connect(m_viewPart, SIGNAL(setSelection(const Diff2::Difference*)),
-            m_navTreePart, SLOT(slotSetSelection(const Diff2::Difference*)));
+    connect(m_navTreePart, SIGNAL(selectionChanged(const KompareDiff2::Difference*)),
+            m_viewPart, SIGNAL(selectionChanged(const KompareDiff2::Difference*)));
+    connect(m_viewPart, SIGNAL(setSelection(const KompareDiff2::Difference*)),
+            m_navTreePart, SLOT(slotSetSelection(const KompareDiff2::Difference*)));
 
     // This is the interpart interface, it is signal and slot based so no "real" nterface here
     // All you have to do is connect the parts from your application.
-    // These just point to the method with the same name in the KompareModelList or get called
-    // from the method with the same name in KompareModelList.
+    // These just point to the method with the same name in the ModelList or get called
+    // from the method with the same name in ModelList.
 
     // There is currently no applying possible from the navtreepart to the viewpart
     connect(m_viewPart, SIGNAL(applyDifference(bool)),
             m_navTreePart, SLOT(slotApplyDifference(bool)));
     connect(m_viewPart, SIGNAL(applyAllDifferences(bool)),
             m_navTreePart, SLOT(slotApplyAllDifferences(bool)));
-    connect(m_viewPart, SIGNAL(applyDifference(const Diff2::Difference*,bool)),
-            m_navTreePart, SLOT(slotApplyDifference(const Diff2::Difference*,bool)));
+    connect(m_viewPart, SIGNAL(applyDifference(const KompareDiff2::Difference*,bool)),
+            m_navTreePart, SLOT(slotApplyDifference(const KompareDiff2::Difference*,bool)));
 
     // Hook up the KomparePart -> KompareShell communication
     connect(m_viewPart, SIGNAL(setStatusBarModelInfo(int,int,int,int,int)),
@@ -260,13 +260,13 @@ void KompareShell::saveProperties(KConfigGroup& config)
     // The 'config' object points to the session managed
     // config file.  Anything you write here will be available
     // later when this app is restored
-    if (m_mode == Kompare::ComparingFiles)
+    if (m_mode == KompareDiff2::ComparingFiles)
     {
         config.writeEntry("Mode", "ComparingFiles");
         config.writePathEntry("SourceUrl", m_sourceURL.url());
         config.writePathEntry("DestinationUrl", m_destinationURL.url());
     }
-    else if (m_mode == Kompare::ShowingDiff)
+    else if (m_mode == KompareDiff2::ShowingDiff)
     {
         config.writeEntry("Mode", "ShowingDiff");
         config.writePathEntry("DiffUrl", m_diffURL.url());
@@ -285,7 +285,7 @@ void KompareShell::readProperties(const KConfigGroup& config)
     QString mode = config.readEntry("Mode", "ComparingFiles");
     if (mode == QLatin1String("ComparingFiles"))
     {
-        m_mode  = Kompare::ComparingFiles;
+        m_mode  = KompareDiff2::ComparingFiles;
         m_sourceURL  = QUrl::fromLocalFile(config.readPathEntry("SourceUrl", QString()));
         m_destinationURL = QUrl::fromLocalFile(config.readPathEntry("DestinationFile", QString()));
 
@@ -295,7 +295,7 @@ void KompareShell::readProperties(const KConfigGroup& config)
     }
     else if (mode == QLatin1String("ShowingDiff"))
     {
-        m_mode = Kompare::ShowingDiff;
+        m_mode = KompareDiff2::ShowingDiff;
         m_diffURL = QUrl::fromLocalFile(config.readPathEntry("DiffUrl", QString()));
 
         viewPart()->readProperties(const_cast<KConfig*>(config.config()));
